@@ -1,5 +1,5 @@
 import os
-from typing import List
+from typing import List, Optional
 
 import agate as ag
 from agate import data_types
@@ -23,6 +23,8 @@ class SeedRunner(NodeRunner):
     }
 
     def run(self, node: Node) -> DryRunResult:
+        if not node.root_path:
+            raise ValueError(f"Node {node.unique_id} does not have `root_path`")
         full_path = os.path.join(node.root_path, node.original_file_path)
         with open(full_path, "r", encoding="utf-8-sig") as f:
             csv_table = ag.Table.from_csv(f)
@@ -37,3 +39,6 @@ class SeedRunner(NodeRunner):
         return DryRunResult(
             node=node, table=schema, status=DryRunStatus.SUCCESS, exception=None
         )
+
+    def validate_node(self, node: Node) -> Optional[DryRunResult]:
+        return None
